Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(64)

Unified Diff: pkg/front_end/test/kernel_generator_test.dart

Issue 2993113003: Revert "Switch FE to use the libraries.json format." (Closed)
Patch Set: Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/front_end/test/kernel_generator_test.dart
diff --git a/pkg/front_end/test/kernel_generator_test.dart b/pkg/front_end/test/kernel_generator_test.dart
index cbed95ef8e44f39cd7d89ee567c3d4c493c4f9e2..6620a094bf3f53029aed232d06b247cb2229aae5 100644
--- a/pkg/front_end/test/kernel_generator_test.dart
+++ b/pkg/front_end/test/kernel_generator_test.dart
@@ -17,7 +17,7 @@ main() {
test('compiler fails if it cannot find sdk sources', () async {
var errors = [];
var options = new CompilerOptions()
- ..librariesSpecificationUri = invalidCoreLibsSpecUri
+ ..dartLibraries = invalidCoreLibs
..sdkSummary = null
..compileSdk = true // To prevent FE from loading an sdk-summary.
..onError = (e) => errors.add(e);
@@ -42,10 +42,9 @@ main() {
test('by default program is compiled using summaries', () async {
var options = new CompilerOptions()
- // Note: we define [librariesSpecificationUri] with a specification that
- // contains broken URIs to ensure we do not attempt to lookup for
- // sources of the sdk directly.
- ..librariesSpecificationUri = invalidCoreLibsSpecUri;
+ // Note: we define [dartLibraries] with broken URIs to ensure we do not
+ // attempt to lookup for sources of the sdk directly.
+ ..dartLibraries = invalidCoreLibs;
var program =
await compileScript('main() => print("hi");', options: options);
var core = program.libraries.firstWhere(isDartCoreLibrary);

Powered by Google App Engine
This is Rietveld 408576698